# GretyT Signer


## Local Setup

- setup selenium with driver (we are using geckodriver).
- create a virtualenv.
- install the requirements using `requirements.txt`.
- create a `.env` file use `.env-example` for reference.
